@@ -1,15 +1,16 @@
 import sys
 from PyQt5 import QtWidgets
 from PyQt5.QtWidgets import QMainWindow, QApplication, QMessageBox
-from telas.tela_main import Tela_main
-from telas.tela_mapa import Tela_mapa
-from telas.tela_marcador import Tela_marcador
-from telas.tela_calc_dist import Tela_calc_dist
-from telas.tela_dados_meteoro import Tela_dados_meteoro
-from telas.tela_conversor import Tela_conversor
+from tela_main import Tela_main
+from tela_mapa import Tela_mapa
+from tela_marcador import Tela_marcador
+from tela_calc_dist import Tela_calc_dist
+from tela_dados_meteoro import Tela_dados_meteoro
+from tela_conversor import Tela_conversor
 from classes import Map, Coordinate, Location, OSMGeocoder
 import webbrowser
 
+
 class UiMain( QtWidgets.QWidget ):
     def setupUi(self, Main):
         Main.setObjectName( 'Main' )
